==> qore-1.14.2.tar.bz2: qore-1.14.2/docs/modules/PgsqlSqlUtilBase/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore PgsqlSqlUtilBase Module Reference", "index.html", [
    [ "PgsqlSqlUtilBase Module", "index.html", [
      [ "PgsqlSqlUtilBase Module Introduction", "index.html#pgsqlsqlutilbaseintro", null ],
      [ "Schema Management on PostgreSQL", "index.html#pgsql_schema_management", [
        [ "Type Mapping", "index.html#pgsql_type_mapping", null ],
        [ "Additional Object Types Supported", "index.html#pgsql_other_objects", null ],
        [ "Types", "index.html#pgsql_types", null ],
        [ "Function Handling", "index.html#pgsql_functions", null ]
      ] ],
      [ "Release Notes", "index.html#pgsql_relnotes", [
        [ "PgsqlSqlUtilBase v1.8", "index.html#pgsqlsqlutilbasev18", null ],
        [ "PgsqlSqlUtilBase v1.7.1", "index.html#pgsqlsqlutilbasev171", null ],
        [ "PgsqlSqlUtilBase v1.7", "index.html#pgsqlsqlutilbasev17", null ],
        [ "PgsqlSqlUtilBase v1.6", "index.html#pgsqlsqlutilbasev16", null ],
        [ "PgsqlSqlUtilBase v1.5.3", "index.html#pgsqlsqlutilbasev151", null ],
        [ "PgsqlSqlUtilBase v1.5", "index.html#pgsqlsqlutilbasev15", null ],
        [ "PgsqlSqlUtilBase v1.4.1", "index.html#pgsqlsqlutilbasev141", null ],
        [ "PgsqlSqlUtilBase v1.4", "index.html#pgsqlsqlutilbasev14", null ],
        [ "PgsqlSqlUtilBase v1.3.1", "index.html#pgsqlsqlutilbasev131", null ],
        [ "PgsqlSqlUtilBase v1.3", "index.html#pgsqlsqlutilbasev13", null ],
        [ "PgsqlSqlUtilBase v1.2.1", "index.html#pgsqlsqlutilbasev121", null ],
        [ "PgsqlSqlUtilBase v1.2", "index.html#pgsqlsqlutilbasev12", null ],
        [ "PgsqlSqlUtilBase v1.1.2", "index.html#pgsqlsqlutilbasev112", null ],
        [ "PgsqlSqlUtilBase v1.1.1", "index.html#pgsqlsqlutilbasev111", null ],
        [ "PgsqlSqlUtilBase v1.1", "index.html#pgsqlsqlutilbasev11", null ],
        [ "PgsqlSqlUtilBase v1.0", "index.html#pgsqlsqlutilbasev10", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_pgsql_sql_util_base_1_1_pgsql_table.html#afd616ea4ee5e1f12a401976057240e02"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.18.0.tar.bz2: qore-1.18.0/docs/modules/PgsqlSqlUtilBase/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore PgsqlSqlUtilBase Module Reference", "index.html", [
    [ "MssqlSqlUtilBase Module", "index.html", [
      [ "MssqlSqlUtilBase Module Introduction", "index.html#mssqlsqlutilbaseintro", null ],
      [ "SQL Operations on MS SQL Server Databases", "index.html#mssql_sql_operations", null ],
      [ "Schema Management with the MS SQL Databses", "index.html#mssql_schema_management", [
        [ "Type Mapping", "index.html#mssql_type_mapping", null ],
        [ "MssqlSqlUtilBase v1.0", "index.html#MssqlSqlUtilBasev10", null ]
      ] ]
    ] ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"class_mssql_sql_util_base_1_1_mssql_trigger.html#a342cfa83c689d2e6150617cde05387d2"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
